==> hoichess_0.4.3.orig.tar.gz: hoichess-0.4.3.orig/src/debug.cc <==
/* $Id: debug.cc 1141 2006-02-19 16:54:43Z holger $
 *
 * HoiChess/debug.cc
 *
 * Copyright (C) 2005 Holger Ruckdeschel <holger@hoicher.de>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

#include "common.h"
#include "debug.h"
#include "thread.h"
#include "eval.h"	/* for debug_print_storagesizes() */
#include "tree.h"	/* for debug_print_storagesizes() */
#include "util.h"

#include <errno.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>


void __debug_helper::__dbg(unsigned int level, const char * fmt, ...)
{
	if (debug < level) {
		return;
	}

	if (mutex) {
		mutex->lock();
	}
	
	fprintf(fp, "%s:%d: %s: debug(%d): ", file, line, function, level);

	va_list args;
	va_start(args, fmt);
	vfprintf(fp, fmt, args);
	va_end(args);

	if (fmt[strlen(fmt)-1] != '\n') {
		fprintf(fp, "\n");
	}

	if (mutex) {
		mutex->unlock();
	}
}

void __debug_helper::__warn(const char * fmt, ...)
{
	if (mutex) {
		mutex->lock();
	}
	
	fprintf(fp, "%s:%d: %s: warning: ", file, line, function);

	va_list args;
	va_start(args, fmt);
	vfprintf(fp, fmt, args);
	va_end(args);

	if (fmt[strlen(fmt)-1] != '\n') {
		fprintf(fp, "\n");
	}

	if (mutex) {
		mutex->unlock();
	}
}

void __debug_helper::__bug(const char * fmt, ...)
{
	if (mutex) {
		mutex->lock();
	}

	fprintf(fp, "%s:%d: %s: ", file, line, function);

	va_list args;
	va_start(args, fmt);
	vfprintf(fp, fmt, args);
	va_end(args);

	if (fmt[strlen(fmt)-1] != '\n') {
		fprintf(fp, "\n");
	}

	fprintf(fp, "This is a bug in %s. Please report it to %s.\n",
			PROGNAME, AUTHOR_EMAIL);

	if (mutex) {
		mutex->unlock();
	}

	raise(SIGABRT);
	exit(EXIT_FAILURE);
}


void debug_print_compiletime_config()
{
	const char * platform = 
#if defined(__unix__)
		"unix";
#elif defined(WIN32) && defined(__MINGW32__)
		"mingw32";
#elif defined(WIN32)
		"win32";
#else
		"unknown";
#endif	
	printf("Platform: %s\n", platform);
	
	
	printf("Compile-time configuration:");
	
#ifdef USE_UNMAKE_MOVE
	printf(" USE_UNMAKE_MOVE");
#endif
#ifdef USE_HASH
	printf(" USE_HASH");
#endif
#ifdef USE_IID
	printf(" USE_IID");
#endif
#ifdef USE_PVS
	printf(" USE_PVS");
#endif
#ifdef USE_HISTORY
	printf(" USE_HISTORY");
#endif
#ifdef USE_KILLER
	printf(" USE_KILLER");
#endif
#ifdef USE_NULLMOVE
	printf(" USE_NULLMOVE");
#endif
#ifdef USE_EVALCACHE
	printf(" USE_EVALCACHE");
#endif
	
	printf("\n");
}



#define PRNT(x) printf(" " #x "=%u", (x))

void debug_print_storagesizes()
{
	printf("Storage sizes:");

	PRNT(sizeof(Bitboard));
	PRNT(sizeof(Board));
	PRNT(sizeof(Move));
	PRNT(sizeof(Movelist));
	PRNT(sizeof(HashEntry));
	PRNT(sizeof(PawnHashEntry));
	PRNT(EvaluationCache::SIZEOF_ENTRY);
	PRNT(sizeof(Node));
	
	printf("\n");
}

==> hoichess_0.5.1.orig.tar.gz: hoichess-0.5.1/src/debug.cc <==
/* $Id: debug.cc 1227 2006-06-16 17:58:50Z holger $
 *
 * HoiChess/debug.cc
 *
 * Copyright (C) 2005 Holger Ruckdeschel <holger@hoicher.de>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

#include "common.h"
#include "debug.h"
#include "thread.h"
#include "eval.h"	/* for debug_print_storagesizes() */
#include "tree.h"	/* for debug_print_storagesizes() */
#include "util.h"

#include <errno.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <iostream>


void __debug_helper::__dbg(unsigned int level, const char * fmt, ...)
{
	if (debug < level) {
		return;
	}

	if (mutex) {
		mutex->lock();
	}
	
	fprintf(fp, "%s:%d: %s: debug(%d): ", file, line, function, level);

	va_list args;
	va_start(args, fmt);
	vfprintf(fp, fmt, args);
	va_end(args);

	if (fmt[strlen(fmt)-1] != '\n') {
		fprintf(fp, "\n");
	}

	if (mutex) {
		mutex->unlock();
	}
}

void __debug_helper::__warn(const char * fmt, ...)
{
	if (mutex) {
		mutex->lock();
	}
	
	fprintf(fp, "%s:%d: %s: warning: ", file, line, function);

	va_list args;
	va_start(args, fmt);
	vfprintf(fp, fmt, args);
	va_end(args);

	if (fmt[strlen(fmt)-1] != '\n') {
		fprintf(fp, "\n");
	}

	if (mutex) {
		mutex->unlock();
	}
}

void __debug_helper::__bug(const char * fmt, ...)
{
	if (mutex) {
		mutex->lock();
	}

	fprintf(fp, "%s:%d: %s: ", file, line, function);

	va_list args;
	va_start(args, fmt);
	vfprintf(fp, fmt, args);
	va_end(args);

	if (fmt[strlen(fmt)-1] != '\n') {
		fprintf(fp, "\n");
	}

	fprintf(fp, "This is a bug in %s. Please report it to %s.\n",
			PROGNAME, AUTHOR_EMAIL);

	if (mutex) {
		mutex->unlock();
	}

	raise(SIGABRT);
	exit(EXIT_FAILURE);
}


void debug_print_compiletime_config()
{
	const char * platform = 
#if defined(__unix__)
		"unix";
#elif defined(WIN32) && defined(__MINGW32__)
		"mingw32";
#elif defined(WIN32)
		"win32";
#else
		"unknown";
#endif	
	printf("Platform: %s\n", platform);
	
	
	printf("Compile-time configuration:\n");
#include "debug_printconfig.h"	
	printf("\n");
}



#define PRNT(x) printf(" " #x "=%u", (x))

void debug_print_storagesizes()
{
	printf("Storage sizes:");

	PRNT(sizeof(Bitboard));
	PRNT(sizeof(Board));
	PRNT(sizeof(Move));
	PRNT(sizeof(Movelist));
	PRNT(sizeof(HashEntry));
	PRNT(sizeof(PawnHashEntry));
	PRNT(EvaluationCache::SIZEOF_ENTRY);
	PRNT(sizeof(Node));
	
	printf("\n");
}
